@@ -3,7 +3,7 @@ BEGIN {
   $Emacs::PodMode::AUTHORITY = 'cpan:SCHWIGON';
 }
 BEGIN {
-  $Emacs::PodMode::VERSION = '1.03';
+  $Emacs::PodMode::VERSION = '1.04';
 } 
 # ABSTRACT: Emacs major mode for editing .pod-files
 
@@ -19,7 +19,7 @@ Emacs::PodMode - Emacs major mode for editing .pod-files
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 DESRIPTION
 
@@ -31,7 +31,8 @@ writing POD.
 Put the file F<pod-mode.el> into your load-path and the following into
 your F<~/.emacs>:
 
-    (require 'pod-mode)
+    (autoload 'pod-mode "pod-mode"
+      "Mode for editing POD files" t)
 
 To associate pod-mode with .pod files add the following to your
 F<~/.emacs>:
